<?php
/**
 * TechnoArea functions and definitions
 *
 * @package TechnoArea
 * @since TechnoArea 1.0
 */
 
 /**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since TechnoArea 1.0
 */
if ( ! isset( $content_width ) )
    $content_width = 650; /* pixels */

if ( ! function_exists( 'TechnoArea_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since TechnoArea 1.0
 */
function TechnoArea_setup() {
 
    /**
     * Custom template tags for this theme.
     */
    require( get_template_directory() . '/inc/template-tags.php' );
 
    /**
     * Custom functions that act independently of the theme templates
     */
    require( get_template_directory() . '/inc/tweaks.php' );
	
	  require( get_template_directory() . '/inc/admin.php' );
 
    /**
     * Make theme available for translation
     * Translations can be filed in the /languages/ directory
     * If you're building a theme based on TechnoArea, use a find and replace
     * to change 'TechnoArea' to the name of your theme in all the template files
     */
    load_theme_textdomain( 'TechnoArea', get_template_directory() . '/languages' );
 
    /**
     * Add default posts and comments RSS feed links to head
     */
    add_theme_support( 'automatic-feed-links' );
 
    /**
     * Enable support for the Aside Post Format
     */
    add_theme_support( 'post-formats', array( 'aside' ) );
 
    /**
     * This theme uses wp_nav_menu() in one location.
     */
    register_nav_menus( array(
        'primary' => __( 'Primary Menu', 'TechnoArea' ),
    ) );
}
endif; // TechnoArea_setup
add_action( 'after_setup_theme', 'TechnoArea_setup' );

/**
 * Enqueue scripts and styles
 */
function TechnoArea_scripts() {
    wp_enqueue_style( 'style', get_stylesheet_uri() );
 
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
	
	wp_enqueue_script( 'customscript', get_template_directory_uri() . '/js/customscript.js', array(), '20120206', true );
	
	wp_enqueue_script( 'modernizr.min', get_template_directory_uri() . '/js/modernizr.min.js', array(), '20120206', true );
 
}
add_action( 'wp_enqueue_scripts', 'TechnoArea_scripts' );

/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since TechnoArea 1.0
 */
function TechnoArea_widgets_init() {
    register_sidebar( array(
        'name' => __( 'Primary Widget Area', 'TechnoArea' ),
        'id' => 'sidebar-1',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h1 class="widget-title">',
        'after_title' => '</h1>',
    ) );
 
    register_sidebar( array(
        'name' => __( 'Secondary Widget Area', 'TechnoArea' ),
        'id' => 'sidebar-2',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h1 class="widget-title">',
        'after_title' => '</h1>',
    ) );
}
add_action( 'widgets_init', 'TechnoArea_widgets_init' );

// Breadcrumb
function get_breadcrumbs()
{
    global $wp_query;

    if ( !is_home() ){

        // Start the UL
        echo '<ul class="breadcrumbs">';
        // Add the Home link
        echo '<li><a href="'. get_settings('home') .'">'. get_bloginfo('name') .'</a></li>';

        if ( is_category() )
        {
            $catTitle = single_cat_title( "", false );
            $cat = get_cat_ID( $catTitle );
            echo "<li>  ". get_category_parents( $cat, TRUE, "  " ) ."</li>";
        }
        elseif ( is_archive() && !is_category() )
        {
            echo "<li>  Archives</li>";
        }
        elseif ( is_search() ) {

            echo "<li>  Search Results</li>";
        }
        elseif ( is_404() )
        {
            echo "<li>  404 Not Found</li>";
        }
        elseif ( is_single() )
        {
            $category = get_the_category();
            $category_id = get_cat_ID( $category[0]->cat_name );

            echo '<li>  '. get_category_parents( $category_id, TRUE, "  " );
            echo the_title('','', FALSE) ."</li>";
        }
        elseif ( is_page() )
        {
            $post = $wp_query->get_queried_object();

            if ( $post->post_parent == 0 ){

                echo "<li>  ".the_title('','', FALSE)."</li>";

            } else {
                $title = the_title('','', FALSE);
                $ancestors = array_reverse( get_post_ancestors( $post->ID ) );
                array_push($ancestors, $post->ID);

                foreach ( $ancestors as $ancestor ){
                    if( $ancestor != end($ancestors) ){
                        echo '<li>  <a href="'. get_permalink($ancestor) .'">'. strip_tags( apply_filters( 'single_post_title', get_the_title( $ancestor ) ) ) .'</a></li>';
                    } else {
                        echo '<li>  '. strip_tags( apply_filters( 'single_post_title', get_the_title( $ancestor ) ) ) .'</li>';
                    }
                }
            }
        }

        // End the UL
        echo "</ul>";
    }
}
function updateURL() {
  /* Only target single post pages in WordPress */
  if ( is_single() ) { ?>
   <script> 
     /* The script runs asynchronously and won't affect page loading time */
     setTimeout (function () {
       /* We perform this check since older browsers may not support history.pushState*/
       if (typeof history.pushState === "function") 
       {
         /* Calculate the screen width of the device */
         var width = window.innerWidth || screen.width; 
        
         /* Only target mobile devices with width < 768 pixels */
         if (width < 768) 
         {
          /* Only change the URL but not the title in the address bar */
          history.pushState(null, null, "/?p=<?php the_ID(); ?>"); 
         } 
       } 
     }, 10 ); 
   </script>
<? }
}
 
/* Insert the JavaScript in your template footer */
add_action ("wp_footer", "updateURL");